@@ -20,26 +20,12 @@
 
 #define QT_FEATURE_framework -1
 
-#define QT_FEATURE_cxx11 1
-
-#define QT_FEATURE_cxx14 1
-
-#define QT_FEATURE_cxx17 1
-
-#define QT_FEATURE_cxx1z 1
-
 #define QT_FEATURE_cxx20 -1
 
 #define QT_FEATURE_cxx2a -1
 
 #define QT_FEATURE_cxx2b -1
 
-#define QT_FEATURE_cxx2b -1
-
-#define QT_FEATURE_c99 1
-
-#define QT_FEATURE_c11 1
-
 #define QT_FEATURE_reduce_relocations 1
 
 #define QT_FEATURE_signaling_nan 1
@@ -65,13 +51,15 @@
 #define QT_FEATURE_opensslv30 1
 
 
-#define QT_VERSION_STR "6.5.2"
+#define QT_VERSION_STR "6.7.0"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 5
+#define QT_VERSION_MINOR 7
 
-#define QT_VERSION_PATCH 2
+#define QT_VERSION_PATCH 0
+
+#define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
 #define QT_USE_PROTECTED_VISIBILITY
